aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.BL/Enumerations
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2025-04-10 12:47:30 +0300
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2025-04-10 12:47:30 +0300
commit152ce566d316f80a7782b0504b795e890c2998f0 (patch)
treeb5b3e56c32b9ebde0ff2244462d453f59a0cadbd /Software/Visual_Studio/Tango.BL/Enumerations
parentaf33c539cc7034dc334fd25dc743e36d787c9cbf (diff)
downloadTango-152ce566d316f80a7782b0504b795e890c2998f0.tar.gz
Tango-152ce566d316f80a7782b0504b795e890c2998f0.zip
Resume global progress modification.
Events updated.
Diffstat (limited to 'Software/Visual_Studio/Tango.BL/Enumerations')
-rw-r--r--Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs110
1 files changed, 88 insertions, 22 deletions
diff --git a/Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs b/Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs
index 56f8c77cd..02c1333e8 100644
--- a/Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs
+++ b/Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs
@@ -3662,6 +3662,30 @@ namespace Tango.BL.Enumerations
E_TUNNEL_SUCTION_FLOW_TOO_LOW = 111008,
/// <summary>
+ /// (Dryer push flow too high. Cannot execute job)
+ /// </summary>
+ [Description("Dryer push flow too high. Cannot execute job")]
+ E_DRYER_PUSH_FLOW_TOO_HIGH = 111009,
+
+ /// <summary>
+ /// (Dryer suction flow too high. Cannot execute job)
+ /// </summary>
+ [Description("Dryer suction flow too high. Cannot execute job")]
+ E_DRYER_SUCTION_FLOW_TOO_HIGH = 111010,
+
+ /// <summary>
+ /// (Tunnel push flow too high. Cannot execute job)
+ /// </summary>
+ [Description("Tunnel push flow too high. Cannot execute job")]
+ E_TUNNEL_PUSH_FLOW_TOO_HIGH = 111011,
+
+ /// <summary>
+ /// (Tunnel suction flow too high. Cannot execute job)
+ /// </summary>
+ [Description("Tunnel suction flow too high. Cannot execute job")]
+ E_TUNNEL_SUCTION_FLOW_TOO_HIGH = 111012,
+
+ /// <summary>
/// (Pressure in @ ink line too high. Cannot execute job)
/// </summary>
[Description("Pressure in @ ink line too high. Cannot execute job")]
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_10_MID_TANK_LOW_LEVEL = 112044,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_1_MID_TANK_FILL_TIMEOUT = 112045,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_2_MID_TANK_FILL_TIMEOUT = 112046,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_3_MID_TANK_FILL_TIMEOUT = 112047,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_4_MID_TANK_FILL_TIMEOUT = 112048,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_5_MID_TANK_FILL_TIMEOUT = 112049,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_6_MID_TANK_FILL_TIMEOUT = 112050,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_7_MID_TANK_FILL_TIMEOUT = 112051,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_8_MID_TANK_FILL_TIMEOUT = 112052,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_9_MID_TANK_FILL_TIMEOUT = 112053,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_10_MID_TANK_FILL_TIMEOUT = 112054,
/// <summary>
@@ -4094,9 +4118,9 @@ namespace Tango.BL.Enumerations
E_INK_LINE_11_MID_TANK_LOW_LEVEL = 112071,
/// <summary>
/// (Failed to fill @ tank. Cannot execute job)
/// </summary>
- [Description("Failed to fill @ tank. Cannot execute job")]
+ [Description("Cannot fill @ tank. Replace @ jerrycan to start new job")]
E_INK_LINE_11_MID_TANK_FILL_TIMEOUT = 112072,
/// <summary>
@@ -4171,5 +4195,47 @@ namespace Tango.BL.Enumerations
[Description("The @ tank is empty. Cannot execute job")]
E_INK_LINE_11_MID_TANK_EMPTY = 112084,
+ /// <summary>
+ /// (Lubricant Jerrycan is empty)
+ /// </summary>
+ [Description("Lubricant Jerrycan is empty")]
+ E_LUBRICANT_JERRYCAN_IS_EMPTY = 112085,
+
+ /// <summary>
+ /// (Lubricant jerrycan is not present. Cannot execute job)
+ /// </summary>
+ [Description("Lubricant jerrycan is not present. Cannot execute job")]
+ E_LUBRICANT_JERRYCAN_NOT_PRESENT = 112086,
+
+ /// <summary>
+ /// (Waste jerrycan is not present. Cannot execute job)
+ /// </summary>
+ [Description("Waste jerrycan is not present. Cannot execute job")]
+ E_WASTE_JERRYCAN_NOT_PRESENT = 113000,
+
+ /// <summary>
+ /// (Waste jerrycan is full. Cannot execute job)
+ /// </summary>
+ [Description("Waste jerrycan is full. Cannot execute job")]
+ E_WASTE_JERRYCAN_IS_FULL = 113001,
+
+ /// <summary>
+ /// (Waste jerrycan and sub-tanks are full. Cannot execute job)
+ /// </summary>
+ [Description("Waste jerrycan and sub-tanks are full. Cannot execute job")]
+ E_WASTE_JERRYCAN_AND_SUB_TANKS_ARE_FULL = 113002,
+
+ /// <summary>
+ /// (No draining from IDU-Chimney sub-tank. Cannot execute job)
+ /// </summary>
+ [Description("No draining from IDU-Chimney sub-tank. Cannot execute job")]
+ E_NO_DRAINING_FROM_IDU_CHIMNEY_SUB_TANK = 113003,
+
+ /// <summary>
+ /// (No draining from IFS-Dryer sub-tank. Cannot execute job)
+ /// </summary>
+ [Description("No draining from IFS-Dryer sub-tank. Cannot execute job")]
+ E_NO_DRAINING_FROM_IFS_DRYER_SUB_TANK = 113004,
+
}
}
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_10_MID_TANK_LOW_LEVEL = 112044,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_1_MID_TANK_FILL_TIMEOUT = 112045,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_2_MID_TANK_FILL_TIMEOUT = 112046,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_3_MID_TANK_FILL_TIMEOUT = 112047,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_4_MID_TANK_FILL_TIMEOUT = 112048,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_5_MID_TANK_FILL_TIMEOUT = 112049,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_6_MID_TANK_FILL_TIMEOUT = 112050,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_7_MID_TANK_FILL_TIMEOUT = 112051,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_8_MID_TANK_FILL_TIMEOUT = 112052,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -3932,63 +3956,63 @@ namespace Tango.BL.Enumerations
E_INK_LINE_9_MID_TANK_FILL_TIMEOUT = 112053,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>
@@ -4094,9 +4118,9 @@ namespace Tango.BL.Enumerations
E_INK_LINE_11_MID_TANK_LOW_LEVEL = 112071,
/// <summary>
- /// (Failed to fill @ tank. Cannot execute job)
+ /// (Cannot fill @ tank. Replace @ jerrycan to start new job)
/// </summary>